@@ -132,8 +132,8 @@ class KinesisStreamsToLambda(
         *,
         event_source_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        kinesis_stream_props: typing.Any = None,
-        lambda_function_props: typing.Any = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -191,8 +191,8 @@ class KinesisStreamsToLambdaProps:
         *,
         event_source_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        kinesis_stream_props: typing.Any = None,
-        lambda_function_props: typing.Any = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """The properties for the KinesisStreamsToLambda class.
 
@@ -201,6 +201,14 @@ class KinesisStreamsToLambdaProps:
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         """
+        if isinstance(kinesis_stream_props, dict):
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(
+                **kinesis_stream_props
+            )
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {}
         if event_source_props is not None:
             self._values["event_source_props"] = event_source_props
@@ -230,7 +238,7 @@ class KinesisStreamsToLambdaProps:
         return self._values.get("existing_lambda_obj")
 
     @builtins.property
-    def kinesis_stream_props(self) -> typing.Any:
+    def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
         """Optional user-provided props to override the default props for the Kinesis stream.
 
         default
@@ -239,7 +247,9 @@ class KinesisStreamsToLambdaProps:
         return self._values.get("kinesis_stream_props")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Any:
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """User provided props to override the default props for the Lambda function.
 
         default
